==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/prepost/op0049.f <==
      SUBROUTINE OP0049 ( IERR )
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF PREPOST  DATE 05/10/2004   AUTEUR REZETTE C.REZETTE 
C TOLE CRS_513
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
C ......................................................................
      IMPLICIT REAL*8 (A-H,O-Z)
C   - FONCTION REALISEE:
C       COMMANDE PRE_GIBI
C       INTERFACE ENTRE MAILLAGE GIBI    ET FICHIER MAILLAGE ASTER
C   - OUT :
C       IERR   : NON UTILISE
C   - AUTEUR : JACQUES PELLET ET AMD
C ......................................................................
C
C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ---------------------
C
      CHARACTER*6  KBID6
      CHARACTER*8  KBID1
      CHARACTER*9  KBID9
      CHARACTER*4  KBID4
      CHARACTER*14 KBID14
      CHARACTER*16 K16NOM
      INTEGER      ULISOP
C
      CALL INFMAJ()
      CALL GETVIS(' ','UNITE_GIBI'     ,0,1,1,NFIGI,N1)
      CALL GETVIS(' ','UNITE_MAILLAGE' ,0,1,1,NFIAS,N1)
      K16NOM ='                '
      IF ( ULISOP ( NFIGI, K16NOM ) .EQ. 0 )  THEN 
        CALL ULOPEN ( NFIGI,' ',' ','NEW','O')
      ENDIF 
      IF ( ULISOP ( NFIAS, K16NOM ) .EQ. 0 )  THEN 
        CALL ULOPEN ( NFIAS,' ',' ','NEW','O')
      ENDIF 
C
C -- TEST SUR LA PROCEDURE GIBI DE SAUVEGARDE ( SORT OU SAUVER)
C
      READ (NFIGI,1001,END=100) KBID14
      READ (NFIGI,1002) KBID1,KBID9,KBID4
      IF ((KBID1.EQ.'MAILLAGE').AND.(KBID9.EQ.'PROVENANT')
     +   .AND.(KBID4.EQ.'GIBI')) THEN
         CALL UTMESS('F','OP0049','FICHIER GIBI CREE PAR SORT'
     +   //' FORMAT NON SUPPORTE DANS CETTE VERSION')
         GOTO 99999
      ELSEIF (KBID14.EQ.'ENREGISTREMENT') THEN
         REWIND(NFIGI)
         READ (NFIGI,1001) KBID14
         READ (NFIGI,1003) KBID6,IBID
         IF( KBID6.EQ.'NIVEAU' .AND.
     +       IBID.NE.3 .AND. IBID.NE.4 .AND. IBID.NE.5 .AND.
     +       IBID.NE.6 .AND. IBID.NE.8 .AND. IBID.NE.9 .AND.
     +       IBID.NE.10 .AND. IBID.NE.11 .AND. IBID.NE.13 ) THEN
           CALL UTMESS('F','OP0049','FICHIER GIBI NIVEAU ERRONE '
     +           //' : SEULS NIVEAUX 3,4,5,6,8,9,10,11 ET 13 TRAITES')
         ELSE
           REWIND( NFIGI )
           CALL GILIR2 ( NFIGI, IBID, NDIM, NBOBJ )
         ENDIF
      ELSE
         CALL UTMESS('F','OP0049','FICHIER GIBI ERRONE')
      ENDIF
C
      CALL GIECAS(NFIAS,NDIM,NBOBJ)
C
      IF ( ULISOP ( NFIGI, K16NOM ) .NE. 0 )  THEN 
        CALL ULOPEN ( -NFIGI,' ',' ','NEW','O')
      ENDIF

      GOTO 99999
C
 100  CONTINUE
      CALL UTMESS('F','OP0049','LE FICHIER MAILLAGE GIBI EST VIDE')
99999 CONTINUE
C
 1001 FORMAT(1X,A14)
 1002 FORMAT(A8,1X,A9,4X,A4)
 1003 FORMAT(1X,A6,I4)
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/prepost/op0049.f <==
      SUBROUTINE OP0049 ( IERR )
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF PREPOST  DATE 11/05/2005   AUTEUR MCOURTOI M.COURTOIS 
C TOLE CRS_513
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
C ......................................................................
      IMPLICIT REAL*8 (A-H,O-Z)
C   - FONCTION REALISEE:
C       COMMANDE PRE_GIBI
C       INTERFACE ENTRE MAILLAGE GIBI    ET FICHIER MAILLAGE ASTER
C   - OUT :
C       IERR   : NON UTILISE
C   - AUTEUR : JACQUES PELLET ET AMD
C ......................................................................
C
C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ---------------------
C
      CHARACTER*6  KBID6
      CHARACTER*8  KBID1
      CHARACTER*9  KBID9
      CHARACTER*4  KBID4
      CHARACTER*14 KBID14
      CHARACTER*16 K16NOM
      INTEGER      ULISOP
C
      CALL INFMAJ()
      CALL GETVIS(' ','UNITE_GIBI'     ,0,1,1,NFIGI,N1)
      CALL GETVIS(' ','UNITE_MAILLAGE' ,0,1,1,NFIAS,N1)
      K16NOM ='                '
      IF ( ULISOP ( NFIGI, K16NOM ) .EQ. 0 )  THEN 
        CALL ULOPEN ( NFIGI,' ',' ','NEW','O')
      ENDIF 
      IF ( ULISOP ( NFIAS, K16NOM ) .EQ. 0 )  THEN 
        CALL ULOPEN ( NFIAS,' ',' ','NEW','O')
      ENDIF 
C
C -- TEST SUR LA PROCEDURE GIBI DE SAUVEGARDE ( SORT OU SAUVER)
C
      READ (NFIGI,1001,END=100) KBID14
      READ (NFIGI,1002) KBID1,KBID9,KBID4
      IF ((KBID1.EQ.'MAILLAGE').AND.(KBID9.EQ.'PROVENANT')
     +   .AND.(KBID4.EQ.'GIBI')) THEN
         CALL UTMESS('F','OP0049','FICHIER GIBI CREE PAR SORT'
     +   //' FORMAT NON SUPPORTE DANS CETTE VERSION')
         GOTO 99999
      ELSEIF (KBID14.EQ.'ENREGISTREMENT') THEN
         REWIND(NFIGI)
         READ (NFIGI,1001) KBID14
         READ (NFIGI,1003) KBID6,IBID
         IF( KBID6.EQ.'NIVEAU' .AND.
     +       IBID.NE.3 .AND. IBID.NE.4 .AND. IBID.NE.5 .AND.
     +       IBID.NE.6 .AND. IBID.NE.8 .AND. IBID.NE.9 .AND.
     +       IBID.NE.10 .AND. IBID.NE.11 .AND. IBID.NE.13 ) THEN
           CALL UTMESS('A','OP0049','VERSION DE GIBI NON SUPPORTE, '
     +           //'LA LECTURE PEUT ECHOUER !')
         ELSE
           REWIND( NFIGI )
           CALL GILIR2 ( NFIGI, IBID, NDIM, NBOBJ )
         ENDIF
      ELSE
         CALL UTMESS('F','OP0049','FICHIER GIBI ERRONE')
      ENDIF
C
      CALL GIECAS(NFIAS,NDIM,NBOBJ)
C
      IF ( ULISOP ( NFIGI, K16NOM ) .NE. 0 )  THEN 
        CALL ULOPEN ( -NFIGI,' ',' ','NEW','O')
      ENDIF

      GOTO 99999
C
 100  CONTINUE
      CALL UTMESS('F','OP0049','LE FICHIER MAILLAGE GIBI EST VIDE')
99999 CONTINUE
C
 1001 FORMAT(1X,A14)
 1002 FORMAT(A8,1X,A9,4X,A4)
 1003 FORMAT(1X,A6,I4)
      END
